==> fetch.php?media=downloads%3Achannelflow-1.4.1.tgz: channelflow-1.4.1/programs/fieldplots.cpp <==
#include <iostream>
#include <fstream>
#include <iomanip>
#include <stdlib.h>
#include <sys/stat.h>
#include "channelflow/flowfield.h"
#include "channelflow/diffops.h"
#include "channelflow/periodicfunc.h"
#include "channelflow/utilfuncs.h"

using namespace std;
using namespace channelflow;

int main(int argc, char* argv[]) {

  string purpose("produces matlab-readable ascii files of slices and "
		 "spectral properties of a FlowField");

  ArgList args(argc, argv, purpose);

  /***/ string label  = args.getstr ("-l", "--label", "",   "output file stub, defaults to input field stub");
  const string outdir = args.getpath("-o", "--outdir", ".", "output directory");
  const bool spectra  = args.getflag("-s", "--spectra",     "output Fourier and Chebyshev spectra");
  const bool padding  = args.getflag("-pd","--showpad",     "include padded modes in spectra");
  const bool xavg     = args.getflag("-xa", "--xavg",       "plot x-avg u,v,w");
  const bool profile  = args.getflag("-p", "--profiles",    "plot y-profiles of Fourier modes");
  const bool range    = args.getflag("-r", "--range",       "plot a range of Fourier modes");
  const int Kx        = args.getint ("-kx","--kx", 0,       "max kx for Fourier mode profile");
  const int Kz        = args.getint ("-kz","--kz", 0,       "max kz for Fourier mode profile");
  const int xstride   = args.getint ("-xs","--xstride", 1,  "output every xs-th gridpoint value");
  const int ystride   = args.getint ("-ys","--ystride", 1,  "output every ys-th gridpoint value");
  const int zstride   = args.getint ("-zs","--zstride", 1,  "output every zs-th gridpoint value");
  const string odir   = args.getpath("-o", "--odir", "./",  "output directory");
  const string uname  = args.getstr (1, "<flowfield>",      "input field");

  args.check();

  if (label.length() == 0)
    label = stub(uname, ".ff");

  FlowField u(uname);
  plotfield(u, outdir, label, xstride, ystride, zstride);

  if (spectra)
    plotspectra(u,outdir, label, padding);

  if (xavg)
    plotxavg(u,outdir, label);

  if (profile) {
    if (range) {
      if (-abs(Kx) < u.kxmin() || abs(Kx) > u.kxmax() || abs(Kz) > u.kzmax()) {
	cerr << "kx,kz out of range for given flowfield. run fieldprops.x --spec <flowfield>" << endl;
	exit(1);
      }
      for (int kx=0; kx<=Kx; ++kx)
	for (int kz=0; kz<=Kz; ++kz)
	  u.profile(u.mx(kx), u.mz(kz)).save(outdir + label + "_" + i2s(kx) + "_" + i2s(kz));
    }
    else {
      if (Kx < u.kxmin() || Kx > u.kxmax() || Kz < 0 || Kz > u.kzmax()) {
	cerr << "kx,kz out of range for given flowfield. run fieldprops.x --spec <flowfield>" << endl;
	exit(1);
      }
      u.profile(u.mx(Kx), u.mz(Kz)).save(odir + label + i2s(Kx) + i2s(Kz));
    }
  }

  Vector x = periodicpoints(u.Nx(), u.Lx());
  Vector y = chebypoints(u.Ny(), u.a(), u.b());
  Vector z = periodicpoints(u.Nz(), u.Lz());
  ofstream osx((outdir + "x.asc").c_str());
  ofstream osy((outdir + "y.asc").c_str());
  ofstream osz((outdir + "z.asc").c_str());
  for (int nx=0; nx<=u.Nx(); nx += xstride)
    osx << x(nx) << '\n';
  for (int ny=0; ny<u.Ny(); ny += ystride)
    osy << y(ny) << '\n';
  for (int nz=0; nz<=u.Nz(); nz += zstride)
    osz << z(nz) << '\n';
}

==> fetch.php?media=downloads%3Achannelflow-1.4.2.tgz: channelflow-1.4.2/programs/fieldplots.cpp <==
#include <iostream>
#include <fstream>
#include <iomanip>
#include <stdlib.h>
#include <sys/stat.h>
#include "channelflow/flowfield.h"
#include "channelflow/diffops.h"
#include "channelflow/periodicfunc.h"
#include "channelflow/utilfuncs.h"

using namespace std;
using namespace channelflow;

int main(int argc, char* argv[]) {

  string purpose("produces matlab-readable ascii files of slices and "
		 "spectral properties of a FlowField");

  ArgList args(argc, argv, purpose);

  /***/ string label  = args.getstr ("-l", "--label", "",   "output file stub, defaults to input field stub");
  const string outdir = args.getpath("-o", "--outdir", ".", "output directory");
  const bool spectra  = args.getflag("-s", "--spectra",     "output Fourier and Chebyshev spectra");
  const bool padding  = args.getflag("-pd","--showpad",     "include padded modes in spectra");
  const bool xavg     = args.getflag("-xa", "--xavg",       "plot x-avg u,v,w");
  const bool profile  = args.getflag("-p", "--profiles",    "plot y-profiles of Fourier modes");
  const bool range    = args.getflag("-r", "--range",       "plot a range of Fourier modes");
  const int Kx        = args.getint ("-kx","--kx", 0,       "max kx for Fourier mode profile");
  const int Kz        = args.getint ("-kz","--kz", 0,       "max kz for Fourier mode profile");
  const int xstride   = args.getint ("-xs","--xstride", 1,  "output every xs-th gridpoint value");
  const int ystride   = args.getint ("-ys","--ystride", 1,  "output every ys-th gridpoint value");
  const int zstride   = args.getint ("-zs","--zstride", 1,  "output every zs-th gridpoint value");
  const string odir   = args.getpath("-o", "--odir", "./",  "output directory");
  const string uname  = args.getstr (1, "<flowfield>",      "input field");

  args.check();

  if (label.length() == 0) {
    label = stub(uname, ".ff");
    label = stub(label, ".h5");
  }

  FlowField u(uname);
  plotfield(u, outdir, label, xstride, ystride, zstride);

  if (spectra)
    plotspectra(u,outdir, label, padding);

  if (xavg)
    plotxavg(u,outdir, label);

  if (profile) {
    if (range) {
      if (-abs(Kx) < u.kxmin() || abs(Kx) > u.kxmax() || abs(Kz) > u.kzmax()) {
	cerr << "kx,kz out of range for given flowfield. run fieldprops.x --spec <flowfield>" << endl;
	exit(1);
      }
      for (int kx=0; kx<=Kx; ++kx)
	for (int kz=0; kz<=Kz; ++kz)
	  u.profile(u.mx(kx), u.mz(kz)).save(outdir + label + "_" + i2s(kx) + "_" + i2s(kz));
    }
    else {
      if (Kx < u.kxmin() || Kx > u.kxmax() || Kz < 0 || Kz > u.kzmax()) {
	cerr << "kx,kz out of range for given flowfield. run fieldprops.x --spec <flowfield>" << endl;
	exit(1);
      }
      u.profile(u.mx(Kx), u.mz(Kz)).save(odir + label + i2s(Kx) + i2s(Kz));
    }
  }

  Vector x = periodicpoints(u.Nx(), u.Lx());
  Vector y = chebypoints(u.Ny(), u.a(), u.b());
  Vector z = periodicpoints(u.Nz(), u.Lz());
  ofstream osx((outdir + "x.asc").c_str());
  ofstream osy((outdir + "y.asc").c_str());
  ofstream osz((outdir + "z.asc").c_str());
  for (int nx=0; nx<=u.Nx(); nx += xstride)
    osx << x(nx) << '\n';
  for (int ny=0; ny<u.Ny(); ny += ystride)
    osy << y(ny) << '\n';
  for (int nz=0; nz<=u.Nz(); nz += zstride)
    osz << z(nz) << '\n';
}
